# Generated by Django 4.2.20 on 2025-10-02 08:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('newsletters', '0003_alter_contact_id_alter_emailing_id_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='subscription',
            name='unsubscription_reason',
            field=models.TextField(blank=True, default='', verbose_name='unsubscription reason'),
        ),
    ]
