# Generated by Django 4.2 on 2023-05-22 13:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('coop_cms', '0018_auto_20201209_0944'),
    ]

    operations = [
        migrations.AlterField(
            model_name='navtree',
            name='types',
            field=models.ManyToManyField(blank=True, related_name='%(app_label)s_%(class)s_set', to='coop_cms.navtype'),
        ),
    ]
