# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-07-19 14:08

import coop_cms.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('basic_cms', '0004_auto_20161031_1401'),
    ]

    operations = [
        migrations.AlterField(
            model_name='article',
            name='content',
            field=models.TextField(blank=True, default='', verbose_name='content'),
        ),
        migrations.AlterField(
            model_name='article',
            name='logo',
            field=models.ImageField(blank=True, default='', null=True, upload_to=coop_cms.models.get_logo_folder),
        ),
        migrations.AlterField(
            model_name='article',
            name='sites',
            field=models.ManyToManyField(default=[], to='sites.Site', verbose_name='site'),
        ),
        migrations.AlterField(
            model_name='article',
            name='subtitle',
            field=models.TextField(blank=True, default='', verbose_name='subtitle'),
        ),
        migrations.AlterField(
            model_name='article',
            name='summary',
            field=models.TextField(blank=True, default='', verbose_name='Summary'),
        ),
        migrations.AlterField(
            model_name='article',
            name='temp_logo',
            field=models.ImageField(blank=True, default='', null=True, upload_to=coop_cms.models.get_logo_folder),
        ),
        migrations.AlterField(
            model_name='article',
            name='template',
            field=models.CharField(blank=True, default='', max_length=200, verbose_name='template'),
        ),
        migrations.AlterField(
            model_name='article',
            name='title',
            field=models.TextField(blank=True, default='', verbose_name='title'),
        ),
        migrations.AlterField(
            model_name='navtree',
            name='name',
            field=models.CharField(db_index=True, default='default', max_length=100, unique=True, verbose_name='name'),
        ),
    ]
