# Generated by Django 4.2.20 on 2026-03-10 08:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('coop_cms', '0021_newsletter_is_visible'),
    ]

    operations = [
        migrations.CreateModel(
            name='DefaultNewsletterSubjectPrefix',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('subject_prefix', models.CharField(max_length=100)),
            ],
            options={
                'verbose_name': 'Préfixe sujet newsletter par défaut',
                'verbose_name_plural': 'Préfixes sujet newsletter par défaut',
            },
        ),
    ]
