# Generated by Django 4.2.20 on 2026-03-10 08:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('newsletters', '0004_subscription_unsubscription_reason'),
    ]

    operations = [
        migrations.AddField(
            model_name='subscriptiontype',
            name='subject_prefix',
            field=models.CharField(blank=True, default='', help_text='Éviter de mettre tout en majuscule -> SPAM', max_length=100, verbose_name='préfixe du sujet'),
        ),
    ]
