# Generated by Django 4.2.16 on 2024-10-17 08:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('rss_sync', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='rssitem',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='rsssource',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='rsssource',
            name='title',
            field=models.CharField(blank=True, default='', max_length=200, verbose_name='title'),
        ),
    ]
