# Generated by Django 4.2.16 on 2024-10-17 08:55

import coop_cms.models
import datetime
from django.db import migrations, models
import django.db.models.deletion
import django_extensions.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('coop_cms', '0020_alter_alias_id_alter_articlecategory_id_and_more'),
        ('demo_cms', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='article',
            name='login_required',
            field=models.BooleanField(default=False, help_text='If true, only user with login/password will able to access the article', verbose_name='login required'),
        ),
        migrations.AlterField(
            model_name='article',
            name='category',
            field=models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='%(app_label)s_%(class)s_rel', to='coop_cms.articlecategory', verbose_name='Category'),
        ),
        migrations.AlterField(
            model_name='article',
            name='content',
            field=models.TextField(blank=True, default='', verbose_name='content'),
        ),
        migrations.AlterField(
            model_name='article',
            name='created',
            field=django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created'),
        ),
        migrations.AlterField(
            model_name='article',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='article',
            name='logo',
            field=models.ImageField(blank=True, default='', null=True, upload_to=coop_cms.models.get_logo_folder),
        ),
        migrations.AlterField(
            model_name='article',
            name='modified',
            field=django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified'),
        ),
        migrations.AlterField(
            model_name='article',
            name='publication_date',
            field=models.DateTimeField(blank=True, default=datetime.datetime.now, verbose_name='Publication date'),
        ),
        migrations.AlterField(
            model_name='article',
            name='sites',
            field=models.ManyToManyField(default=[], to='sites.site', verbose_name='site'),
        ),
        migrations.AlterField(
            model_name='article',
            name='slug',
            field=models.CharField(db_index=True, max_length=100, null=True, unique=True, validators=[coop_cms.models.validate_slug]),
        ),
        migrations.AlterField(
            model_name='article',
            name='subtitle',
            field=models.TextField(blank=True, default='', verbose_name='subtitle'),
        ),
        migrations.AlterField(
            model_name='article',
            name='summary',
            field=models.TextField(blank=True, default='', verbose_name='Summary'),
        ),
        migrations.AlterField(
            model_name='article',
            name='temp_logo',
            field=models.ImageField(blank=True, default='', null=True, upload_to=coop_cms.models.get_logo_folder),
        ),
        migrations.AlterField(
            model_name='article',
            name='template',
            field=models.CharField(blank=True, default='', max_length=200, verbose_name='template'),
        ),
        migrations.AlterField(
            model_name='article',
            name='title',
            field=models.TextField(blank=True, default='', verbose_name='title'),
        ),
    ]
