# -*- coding: utf-8 -*-
"""
Utilities for Bootstrap CSS framework
"""

from django.apps import AppConfig


class CoopBootstrapAppConfig(AppConfig):
    name = 'coop_cms.apps.coop_bootstrap'
    verbose_name = "coop CMS > Support of Bootstrap CSS framework"
