# Generated by Django 4.2.8 on 2024-01-05 15:01

import datetime
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('coop_cms', '0020_alter_alias_id_alter_articlecategory_id_and_more'),
        ('basic_cms', '0005_auto_20190719_1408'),
    ]

    operations = [
        migrations.AlterField(
            model_name='article',
            name='category',
            field=models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='%(app_label)s_%(class)s_rel', to='coop_cms.articlecategory', verbose_name='Category'),
        ),
        migrations.AlterField(
            model_name='article',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='article',
            name='publication_date',
            field=models.DateTimeField(blank=True, default=datetime.datetime.now, verbose_name='Publication date'),
        ),
        migrations.AlterField(
            model_name='navtree',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='navtree',
            name='types',
            field=models.ManyToManyField(blank=True, related_name='%(app_label)s_%(class)s_set', to='coop_cms.navtype'),
        ),
    ]
