# Generated by Django 4.2.20 on 2025-09-29 15:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('coop_cms', '0020_alter_alias_id_alter_articlecategory_id_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='newsletter',
            name='is_visible',
            field=models.BooleanField(default=True, verbose_name='visible'),
        ),
    ]
