<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">{% load i18n %}
<html xmlns="http://www.w3.org/1999/xhtml" lang="{{LANG}}" xml:lang="{{LANG}}">
<head>
  <meta charset="utf-8">
  <title>{% block title %}{% endblock %}</title>
  {% block jquery_declaration %}
  <script type="text/javascript" charset="utf-8" src="{{ STATIC_URL }}js/jquery-1.7.1.min.js"></script>
  {% endblock %}
  {% block extra_head %}
  {% endblock %}
</head>
<body>
  <div id="main">
    {% include "coop_cms/_messages.html" %}
    <div id="header">
      {% block header %}{% endblock %}
    </div>
    <div id="content">
      {% block custom_content %}
      {% endblock %}
    </div>
    <div id="header">
      {% block footer %}{% endblock %}
    </div>
  </div>
</body>
