{% load i18n coop_utils thumbnail %}
<div class="">
    <h2>
        <a href="{{ item.get_absolute_url }}">
            {% if item.logo %}
            {% thumbnail item.logo "100x100" crop="center" as im %}
                <img src="{{ im.url }}" width="{{ im.width }}" height="{{ im.height }}">
            {% endthumbnail %}
            {% endif %}
            {{ item.title|dehtml }}
        </a>
    </h2>
    <p>{{ item.summary }}</p>
    <div class="date">{{ item.created|date }}</div>
</div>