# Generated by Django 2.2.17 on 2020-12-09 09:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('coop_cms', '0017_auto_20200124_1341'),
    ]

    operations = [
        migrations.AddField(
            model_name='image',
            name='alt_text',
            field=models.CharField(blank=True, default='', max_length=200, verbose_name='alt'),
        ),
        migrations.AddField(
            model_name='image',
            name='title',
            field=models.CharField(blank=True, default='', max_length=200, verbose_name='title'),
        ),
    ]
