{% extends "colorbox/popup_form_base.html" %}
{% load i18n %}

{% block title %}{% trans "Test newsletter" %}{% endblock %}

{% block form_fields %}
<style>
ul {
    padding: 0;
    margin: 0;
    list-style: none;
}

ul li{
    padding: 0;
    margin: 0;
}
</style>
<div>
	{{ block.super }}
</div>
{% endblock %}

{% block form_url %}{% url "coop_cms_test_newsletter" newsletter.id %}{% endblock %}
